READMODE_W

Struct READMODE_W 

pub struct READMODE_W<'a> { /* private fields */ }
Write proxy for field READMODE

Implementations

Source

impl<'a> READMODE_W<'a>

pub fn variant(self, variant: READMODE_A) -> &'a mut W

Writes variant to the field

pub fn no_miss_penalty(self) -> &'a mut W

The NVM Controller (cache system) does not insert wait states on a cache miss. Gives the best system performance.

pub fn low_power(self) -> &'a mut W

Reduces power consumption of the cache system, but inserts a wait state each time there is a cache miss. This mode may not be relevant if CPU performance is required, as the application will be stalled and may lead to increase run time.

pub fn deterministic(self) -> &'a mut W

The cache system ensures that a cache hit or miss takes the same amount of time, determined by the number of programmed flash wait states. This mode can be used for real-time applications that require deterministic execution timings.

pub unsafe fn bits(self, value: u8) -> &'a mut W

Writes raw bits to the field